@@ -1,18 +1,10 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import os
-import collections
+from collections.abc import MutableMapping
 import shlex
 
 from django.conf import settings as _settings
-try:
-    from django.core.signals import setting_changed
-except ImportError:
-    # Django < 1.8
-    from django.test.signals import setting_changed
+from django.core.signals import setting_changed
 from django.dispatch import receiver
-from django.utils.six import string_types
 
 
 DEFAULTS = {
@@ -56,6 +48,9 @@ DEFAULTS = {
 
     'UGLIFYJS_BINARY': '/usr/bin/env uglifyjs',
     'UGLIFYJS_ARGUMENTS': '',
+    
+    'TERSER_BINARY': '/usr/bin/env terser',
+    'TERSER_ARGUMENTS': '--compress',
 
     'CSSMIN_BINARY': '/usr/bin/env cssmin',
     'CSSMIN_ARGUMENTS': '',
@@ -79,11 +74,11 @@ DEFAULTS = {
     'LESS_ARGUMENTS': '',
 
     'MIMETYPES': (
-        (b'text/coffeescript', '.coffee'),
-        (b'text/less', '.less'),
-        (b'text/javascript', '.js'),
-        (b'text/x-sass', '.sass'),
-        (b'text/x-scss', '.scss')
+        (('text/coffeescript'), ('.coffee')),
+        (('text/less'), ('.less')),
+        (('text/javascript'), ('.js')),
+        (('text/x-sass'), ('.sass')),
+        (('text/x-scss'), ('.scss'))
     ),
 
     'EMBED_MAX_IMAGE_SIZE': 32700,
@@ -91,7 +86,7 @@ DEFAULTS = {
 }
 
 
-class PipelineSettings(collections.MutableMapping):
+class PipelineSettings(MutableMapping):
     """
     Container object for pipeline settings
     """
@@ -102,7 +97,7 @@ class PipelineSettings(collections.MutableMapping):
     def __getitem__(self, key):
         value = self.settings[key]
         if key.endswith(("_BINARY", "_ARGUMENTS")):
-            if isinstance(value, string_types):
+            if isinstance(value, (str,)):
                 return tuple(shlex.split(value, posix=(os.name == 'posix')))
             return tuple(value)
         return value
