@@ -1,16 +1,10 @@
-from __future__ import unicode_literals
-
 from django.core.exceptions import MiddlewareNotUsed
 from django.utils.encoding import DjangoUnicodeDecodeError
 from django.utils.html import strip_spaces_between_tags as minify_html
 
 from pipeline.conf import settings
 
-try:
-    # Support for Django 1.10 new MIDDLEWARE setting
-    from django.utils.deprecation import MiddlewareMixin
-except ImportError:  # Django < 1.10
-    MiddlewareMixin = object
+from django.utils.deprecation import MiddlewareMixin
 
 
 class MinifyHTMLMiddleware(MiddlewareMixin):
@@ -22,7 +16,7 @@ class MinifyHTMLMiddleware(MiddlewareMixin):
     def process_response(self, request, response):
         if response.has_header('Content-Type') and 'text/html' in response['Content-Type']:
             try:
-                response.content = minify_html(response.content.strip())
+                response.content = minify_html(response.content.decode('utf-8').strip())
                 response['Content-Length'] = str(len(response.content))
             except DjangoUnicodeDecodeError:
                 pass
