@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.contrib.staticfiles.finders import find
 from django.core.files.base import ContentFile
@@ -109,7 +107,7 @@ class Packager(object):
     def pack(self, package, compress, signal, **kwargs):
         output_filename = package.output_filename
         if self.verbose:
-            print("Saving: %s" % output_filename)
+            print(f"Saving: {output_filename}")
         paths = self.compile(
             package.paths,
             compiler_options=package.compiler_options,
