@@ -19,6 +19,7 @@ SITE_ID = 1
 
 INSTALLED_APPS = [
     'django.contrib.contenttypes',
+    'django.contrib.messages',
     'django.contrib.sites',
     'django.contrib.sessions',
     'django.contrib.staticfiles',
@@ -28,17 +29,16 @@ INSTALLED_APPS = [
     'tests.tests'
 ]
 
-MIDDLEWARE_CLASSES = (
-    'django.contrib.sessions.middleware.SessionMiddleware',
-    'django.contrib.auth.middleware.AuthenticationMiddleware'
-)
 
 ROOT_URLCONF = 'tests.urls'
 
-MIDDLEWARE_CLASSES = (
+MIDDLEWARE = [
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
     'django.middleware.common.CommonMiddleware',
-    'django.middleware.csrf.CsrfViewMiddleware'
-)
+    'django.middleware.csrf.CsrfViewMiddleware',
+]
 
 MEDIA_URL = '/media/'
 
@@ -70,6 +70,28 @@ PIPELINE = {
                 'pipeline/css/urls.css'
             ),
             'output_filename': 'screen.css'
+        },
+        'screen_media': {
+            'source_filenames': (
+                'pipeline/css/first.css',
+                'pipeline/css/second.css',
+                'pipeline/css/urls.css'
+            ),
+            'output_filename': 'screen_media.css',
+            'extra_context': {
+                'media': 'screen and (min-width:500px)',
+            },
+        },
+        'screen_title': {
+            'source_filenames': (
+                'pipeline/css/first.css',
+                'pipeline/css/second.css',
+                'pipeline/css/urls.css'
+            ),
+            'output_filename': 'screen_title.css',
+            'extra_context': {
+                'title': 'Default Style',
+            },
         }
     },
     'JAVASCRIPT': {
@@ -148,6 +170,7 @@ if HAS_NODE:
         'LIVE_SCRIPT_ARGUMENTS': ['--no-header'],
         'YUGLIFY_BINARY': node_exe_path('yuglify'),
         'UGLIFYJS_BINARY': node_exe_path('uglifyjs'),
+        'TERSER_BINARY': node_exe_path('terser'),
         'CSSMIN_BINARY': node_exe_path('cssmin'),
     })
 
@@ -155,7 +178,7 @@ if HAS_NODE and HAS_JAVA:
     PIPELINE.update({
         'CLOSURE_BINARY': [
             JAVA_EXE_PATH, '-jar',
-            os.path.join(NODE_MODULES_PATH, 'google-closure-compiler', 'compiler.jar')],
+            os.path.join(NODE_MODULES_PATH, 'google-closure-compiler-java', 'compiler.jar')],
         'YUI_BINARY': [
             JAVA_EXE_PATH, '-jar',
             glob.glob(os.path.join(NODE_MODULES_PATH, 'yuicompressor', 'build', '*.jar'))[0]]
@@ -171,7 +194,9 @@ TEMPLATES = [
         'DIRS': [local_path('templates')],
         'OPTIONS': {
             'context_processors': [
+                'django.template.context_processors.request',
                 'django.contrib.auth.context_processors.auth',
+                'django.contrib.messages.context_processors.messages',
             ]
         }
     },
