@@ -1,16 +1,10 @@
-from __future__ import unicode_literals
-
 from django.contrib.staticfiles import finders
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.core.management import call_command
 from django.test import TestCase
 from django.test.utils import override_settings
 
-try:
-    from django.test.utils import modify_settings
-except ImportError:
-    # Django < 1.7
-    from tests.utils import modify_settings
+from django.test.utils import modify_settings
 
 from pipeline.collector import default_collector
 from pipeline.storage import PipelineStorage
@@ -18,10 +12,7 @@ from pipeline.storage import PipelineStorage
 from tests.tests.test_compiler import DummyCompiler
 from tests.utils import pipeline_settings
 
-try:
-    from io import StringIO
-except ImportError:
-    from StringIO import StringIO
+from io import StringIO
 
 
 class PipelineNoPathStorage(PipelineStorage):
