@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from jinja2 import Environment, PackageLoader
 
 from django.template import Template, Context
@@ -56,11 +53,19 @@ class DjangoTest(TestCase):
 
     def test_compressed_empty(self):
         rendered = self.render_template(u"""{% load pipeline %}{% stylesheet "unknow" %}""")
-        self.assertEqual(u"", rendered)
+        self.assertEqual(u'', rendered)
 
     def test_compressed_css(self):
         rendered = self.render_template(u"""{% load pipeline %}{% stylesheet "screen" %}""")
-        self.assertEqual(u'<link href="/static/screen.css" rel="stylesheet" type="text/css" />', rendered)
+        self.assertEqual(u'<link href="/static/screen.css" rel="stylesheet" type="text/css" media="all" />', rendered)
+
+    def test_compressed_css_media(self):
+        rendered = self.render_template(u"""{% load pipeline %}{% stylesheet "screen_media" %}""")
+        self.assertEqual(u'<link href="/static/screen_media.css" rel="stylesheet" type="text/css" media="screen and (min-width:500px)" />', rendered)
+
+    def test_compressed_css_title(self):
+        rendered = self.render_template(u"""{% load pipeline %}{% stylesheet "screen_title" %}""")
+        self.assertEqual(u'<link href="/static/screen_title.css" rel="stylesheet" type="text/css" media="all" title="Default Style" />', rendered)
 
     def test_compressed_js(self):
         rendered = self.render_template(u"""{% load pipeline %}{% javascript "scripts" %}""")
